Skip to main contentModule openai
Source - Request
- Response
- ModelVerification
- Outcome of checking whether a model exists at the configured endpoint.
- call
- Calls the OpenAI API with default configuration from settings
- call_with_config
- Calls the OpenAI API with the provided configuration
- classify_model
- Pure decision logic for model verification, decoupled from any network IO so it
can be unit-tested with an injected list of available model ids.
- create_openai_config
- Creates an OpenAI configuration from application settings
- generate_commit_message
- Generates an improved commit message using the provided prompt and diff
Now uses a simplified approach that doesn’t require parsing the diff
- verify_model_exists
- Verifies that
candidate exists at the configured endpoint before it is persisted.